==> nextcloud-30.0.15.tar.bz2: nextcloud/apps/suspicious_login/l10n/tr.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Yeni bir konumdan oturum açıldı",
    "More info about the suspicious IP address available on %s" : "Şüpheli IP adresi hakkında ayrıntılı bilgi %s üzerinde bulunabilir",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Hesabınızda yeni bir oturum açıldı. %s IP adresi şüpheli olarak sınıflandırılmış. Oturumu siz açtıysanız bu iletiyi yok sayabilirsiniz. Siz değilseniz parolanızı değiştirmelisiniz.",
    "Open %s ↗" : "%s aç ↗",
    "Suspicious Login" : "Şüpheli oturum açma",
    "New login detected" : "Oturum açıldı",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Şüpheli IP adreslerinden açılan Nextcloud oturumlarını izler ve uyarır\n\t",
    "Suspicious login detection" : "Şüpheli oturum açma izleme",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "Bu Nextcloud kopyasında şüpheli oturum açma uygulaması kullanıma alınmış. Bu uygulama kullanıcıların oturum açtığı IP adreslerini izler ve bir sınıflayıcı ile değerlendirerek şüpheli bir IP adresinden açılan oturumlarla ilgili uyarıda bulunur.",
    "Training data statistics" : "Model geliştirme verilerinin istastistikleri",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Şu ana kadar uygulama tarafından {total} oturum açma (istemci bağlantıları dahil), {distinct} farklı (IP, UID) grup derlenmiş.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Sınıflayıcı modeli istatistikleri",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Henüz bir sınıflandırma modeli geliştirilmemiş. Bu durum genellikle, uygulamayı yakın zamanda kullanıma aldığınızı gösterir. Bir modelin geliştirilmesi için sağlıklı veriler gerektiğinden, uygulama en az {days} gün oturum açma bilgilerini derlemelidir.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Değerlendirme sırasında, en son modelin (geliştirme {time}) şüpheli oturum açmaları %{recall} oranında yakaladığı (anımsama) ve şüpheli olarak sınıflandırılan oturum açmaların %{precision} oranında gerçekten şüpheli olduğu (doğruluk) bulunmuştur. Model başarımının zamana göre gelişimini aşağıda görebilirsiniz.",
    "Precision" : "Doğruluk",
    "Recall" : "Anımsama"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-31.0.6.tar.bz2: nextcloud/apps/suspicious_login/l10n/tr.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Yeni bir konumdan oturum açıldı",
    "More info about the suspicious IP address available on %s" : "Şüpheli IP adresi hakkında ayrıntılı bilgi %s üzerinde bulunabilir",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Hesabınızda yeni bir oturum açıldı. %s IP adresi şüpheli olarak sınıflandırılmış. Oturumu siz açtıysanız bu iletiyi yok sayabilirsiniz. Siz değilseniz parolanızı değiştirmelisiniz.",
    "Open %s ↗" : "%s aç ↗",
    "Suspicious Login" : "Şüpheli oturum açma",
    "New login detected" : "Oturum açıldı",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Şüpheli IP adreslerinden açılan Nextcloud oturumlarını izler ve uyarır\n\t",
    "Suspicious login detection" : "Şüpheli oturum açma izleme",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "Bu Nextcloud kopyasında şüpheli oturum açma uygulaması etkinleştirilmiş. Bu uygulama kullanıcıların oturum açtığı IP adreslerini izler ve bir sınıflayıcı ile değerlendirerek şüpheli bir IP adresinden açılan oturumlarla ilgili uyarıda bulunur.",
    "Training data statistics" : "Model geliştirme verilerinin istastistikleri",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Şu ana kadar uygulama tarafından {total} oturum açma (istemci bağlantıları dahil), {distinct} farklı (IP, UID) grup derlenmiş.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Sınıflayıcı modeli istatistikleri",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Henüz bir sınıflandırma modeli geliştirilmemiş. Bu durum genellikle, uygulamayı yakın zamanda etkinleştirdiğiniz anlamına gelir. Bir modelin geliştirilmesi için sağlıklı veriler gerektiğinden, uygulama en az {days} gün oturum açma bilgilerini derler.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Değerlendirme sırasında, en son modelin (geliştirme {time}) şüpheli oturum açmaları %{recall} oranında yakaladığı (anımsama) ve şüpheli olarak sınıflandırılan oturum açmaların %{precision} oranında gerçekten şüpheli olduğu (doğruluk) bulunmuştur. Model başarımının zamana göre gelişimini aşağıda görebilirsiniz.",
    "Precision" : "Doğruluk",
    "Recall" : "Anımsama"
},
"nplurals=2; plural=(n > 1);");
